================
salt.modules.pkg
================

.. py:module:: salt.modules.pkg
    :synopsis: A virtual module for installing software packages

``pkg`` is a virtual module that is fulfilled by one of the following modules:

* :mod:`salt.modules.apt`
* :mod:`salt.modules.ebuild`
* :mod:`salt.modules.freebsdpkg`
* :mod:`salt.modules.pacman`
* :mod:`salt.modules.yumpkg`
* :mod:`salt.modules.yumpkg5`
* :mod:`salt.modules.zypper`
* :mod:`salt.modules.brew`
* :mod:`salt.modules.win_pkg`
